#ifndef __DSP_ODDCASTUI_H__
#define __DSP_ODDCASTUI_H__
#ifdef WIN32
#include <winsock2.h>
#include <windows.h>
#endif

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"


#ifdef __BORLANDC__
#pragma hdrstop
#endif

#ifndef WX_PRECOMP
#include "wx/wx.h"
#endif

#include "wx/sizer.h"
#include "wx/timer.h"

#if !wxUSE_CONSTRAINTS
#error You must set wxUSE_CONSTRAINTS to 1 in setup.h!
#endif

#if defined(__WXGTK__) || defined(__WXMOTIF__)
    #define USE_XPM
#endif

#ifdef __WXMSW__
#include <wx/msw/taskbar.h>
#endif

#ifdef __WXMSW__
class PopupSystemTrayIcon: public wxTaskBarIcon
{
public:
    PopupSystemTrayIcon() {};

    virtual void OnMouseMove(wxEvent&);
    virtual void OnLButtonDown(wxEvent&);
    virtual void OnLButtonUp(wxEvent&);
    virtual void OnRButtonDown(wxEvent&);
    virtual void OnRButtonUp(wxEvent&);
    virtual void OnLButtonDClick(wxEvent&);
    virtual void OnRButtonDClick(wxEvent&);

    void OnMenuRestore(wxCommandEvent&);
    void OnMenuExit(wxCommandEvent&);
    void OnMenuQuery(wxCommandEvent&);

    void ProcessAdaptor(wxCommandEvent&);

DECLARE_EVENT_TABLE()
};
#endif


class MyThread : public wxThread
{
public:
    MyThread();

    // thread execution starts here
    virtual void *Entry();

    // called when the thread exits - whether it terminates normally or is
    // stopped with Delete() (but not when it is Kill()ed!)
    virtual void OnExit();


public:
    size_t   m_count;
    
};
class StartThread : public wxThread
{
public:
    StartThread();

    // thread execution starts here
    virtual void *Entry();

    // called when the thread exits - whether it terminates normally or is
    // stopped with Delete() (but not when it is Kill()ed!)
    virtual void OnExit();


public:
    size_t   m_count;
    
};
class SampleThread : public wxThread
{
public:
    SampleThread();

    // thread execution starts here
    virtual void *Entry();

    // called when the thread exits - whether it terminates normally or is
    // stopped with Delete() (but not when it is Kill()ed!)
    virtual void OnExit();


public:
    
};

class MainPanel: public wxWindow
{
public:
    MainPanel(wxFrame *frame, int x, int y, int w, int h);
    virtual ~MainPanel();

	void Connect();
	void Config();
	void VUOnOff();
    void OnSize( wxSizeEvent& event );
	void OnPaint(wxPaintEvent& WXUNUSED(event) );
	//void OnMouseEvent(wxMouseEvent& event);
	void OnLeftMouseButtonDown(wxMouseEvent& event);
	void OnLeftMouseButtonUp(wxMouseEvent& event);
	void OnMouseMotion(wxMouseEvent& event);

	int	mouseDown;
	int mouseDrag;
	int lastMouseX;
	int lastMouseY;
	int	deltaMouseX;
	int	deltaMouseY;
	int	vu_onoff;

	wxFrame		*parentFrame;
	wxBitmap	*pBaseBitmap;
	wxBitmap	pConnectGreenBitmap;
	wxBitmap	pConnectRedBitmap;
	wxBitmap	pConnectPressedBitmap;
	wxBitmap	pConfigBitmap;
	wxBitmap	pVUBitmap;
	wxBitmap	pConfigPressedBitmap;
	wxBitmap	pVUPressedBitmap;
	wxBitmap	pMetadataBitmap;
	wxBitmap	pMetadataPressedBitmap;
	wxRect *serverDesc_Rect;
	wxRect *destination_Rect;
	wxRect *kbpsSent_Rect;
	wxRect *bitrate_Rect;
	wxRect *metadata_Rect;
	wxString	serverDesc;
	wxString	destination;
	wxString	metadata;
	wxString	kbpsSent;
	wxString	bitrate;
	wxString	status;

	wxString	serverDesc_label;
	wxString	destination_label;
	wxString	metadata_label;
	wxString	kbpsSent_label;
	wxString	bitrate_label;
	wxString	status_label;

	wxString	connect_label;
	wxString	config_label;

	wxBitmapButton		*connectButton;
	wxBitmapButton		*configButton;

	MyThread	  *execThread;
	StartThread	  *startThread;
	int			vuShow;
private:
    wxLog *m_logTargetOld;

    DECLARE_EVENT_TABLE()
};

// Define a new application
class MyApp: public wxApp
{
public:
    MyApp();
    bool OnInit();
    int OnExit();

	void setMainStatus(char *pValue);
	void setMainStreamURL(char *pValue);
	void setMainStreamName(char *pValue);
	void setMainMetadata(char *pValue);
	void setMainOutputURL(char *pValue);
	void setInputStatus(char *pValue);
	void setInputTotalRead(char *pValue);
	void setInputBPSRead(char *pValue);
	void setInputServerType(char *pValue);
	void setInputStreamType(char *pValue);
	void setInputBitrate(char *pValue);
	void setOutputStatus(char *pValue);
	void setOutputTotalRead(char *pValue);
	void setOutputBPSRead(char *pValue);
	void setOutputServerType(char *pValue);
	void setOutputServerName(char *pValue);
	void setOutputStreamType(char *pValue);
	void setOutputBitrate(char *pValue);

	SampleThread *execThread;
#ifdef __WXMSW__
    PopupSystemTrayIcon   m_systemtrayicon;
#endif


};

// Define a new frame
class MyTextWindow;
class MyWindow;

class MyFrame: public wxFrame
{
public:

    MainPanel *mainPanel;

    MyFrame(wxFrame *frame, char *title, int x, int y, int w, int h);
	virtual ~MyFrame();

    void OnSize(wxSizeEvent& event);
    void Draw(wxDC& dc, bool draw_bitmaps = TRUE);

    void EditConfig(wxCommandEvent& event);
    void Quit(wxCommandEvent& event);

	int		iconCreated;

private:
    DECLARE_EVENT_TABLE()
};


// Define a new canvas which can receive some events
class MyWindow: public wxWindow
{
public:
    MyWindow(wxFrame *frame, int x, int y, int w, int h, long style = wxRETAINED);
    ~MyWindow();
    void OnPaint(wxPaintEvent& event);

private:    
    DECLARE_EVENT_TABLE()
};


#define LAYOUT_QUIT       100
#define LAYOUT_TEST       101
#define LAYOUT_ABOUT      102
#define LAYOUT_EDIT_CONFIG  103
#define LAYOUT_TEST_SIZER 104
#define LAYOUT_TEST_NB    105

void startItUp();
void closeItDown();
int frameShowHide(bool which);
#endif

class ReconnectTimer : public wxTimer {
public:
    ReconnectTimer();

    void Notify();

private:

};

class VUTimer : public wxTimer {
public:
    VUTimer();

    void Notify();

private:

};

class MetatdataUpdateDlg: public wxDialog
{
public:
	MetatdataUpdateDlg(wxWindow* parent, int x, int y);
    virtual ~MetatdataUpdateDlg();

	wxString	m_Metadata;
	bool		m_metadataLocked;
	wxCheckBox *m_MetadataLockedCtrl;
	wxTextCtrl *m_MetadataCtrl;

};

void setUIMetadata(char *);

